@@ -7,39 +7,39 @@ if False:  # MYPY
 
 _package_data = dict(
     full_package_name='ruamel.yaml',
-    version_info=(0, 15, 26),
-    __version__='0.15.26',
+    version_info=(0, 15, 31),
+    __version__='0.15.31',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     description='ruamel.yaml is a YAML parser/emitter that supports roundtrip preservation of comments, seq/map flow style, and map key order',  # NOQA
     entry_points=None,
     since=2014,
-    extras_require={
-        ':platform_python_implementation=="CPython" and python_version<="2.7"':
-        ['ruamel.ordereddict'],
-        'jinja2': ['ruamel.yaml.jinja2>=0.2'],
-        'docs': ['ryd'],
-    },
+    extras_require={':platform_python_implementation=="CPython" and python_version<="2.7"': [
+            'ruamel.ordereddict',
+        ], 'jinja2': ['ruamel.yaml.jinja2>=0.2'], 'docs': ['ryd']},
     ext_modules=[dict(
-        name='_ruamel_yaml',
+            name='_ruamel_yaml',
             src=['ext/_ruamel_yaml.c', 'ext/api.c', 'ext/writer.c', 'ext/dumper.c',
-                 'ext/loader.c', 'ext/reader.c', 'ext/scanner.c', 'ext/parser.c',
-                 'ext/emitter.c',
+                    'ext/loader.c',
+                    'ext/reader.c',
+                    'ext/scanner.c',
+                    'ext/parser.c',
+                    'ext/emitter.c',
             ],
             lib=[],
-            # test='#include "ext/yaml.h"\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n',  # NOQA
         )],
+            # test='#include "ext/yaml.h"\n\nint main(int argc, char* argv[])\n{\nyaml_parser_t parser;\nparser = parser;  /* prevent warning */\nreturn 0;\n}\n',  # NOQA
     classifiers=[
-        'Programming Language :: Python :: 2.7',
-        'Programming Language :: Python :: 3.3',
-        'Programming Language :: Python :: 3.4',
-        'Programming Language :: Python :: 3.5',
-        'Programming Language :: Python :: 3.6',
-        'Programming Language :: Python :: Implementation :: CPython',
-        'Programming Language :: Python :: Implementation :: PyPy',
-        'Programming Language :: Python :: Implementation :: Jython',
-        'Topic :: Software Development :: Libraries :: Python Modules',
-        'Topic :: Text Processing :: Markup',
+            'Programming Language :: Python :: 2.7',
+            'Programming Language :: Python :: 3.3',
+            'Programming Language :: Python :: 3.4',
+            'Programming Language :: Python :: 3.5',
+            'Programming Language :: Python :: 3.6',
+            'Programming Language :: Python :: Implementation :: CPython',
+            'Programming Language :: Python :: Implementation :: PyPy',
+            'Programming Language :: Python :: Implementation :: Jython',
+            'Topic :: Software Development :: Libraries :: Python Modules',
+            'Topic :: Text Processing :: Markup',
     ],
     keywords='yaml 1.2 parser round-trip preserve quotes order config',
     windows_wheels=True,
